@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "verilog-ext" "0.8.0"
+(define-package "verilog-ext" "20251118.1329"
   "SystemVerilog Extensions."
   '((emacs           "29.1")
     (verilog-mode    "2024.3.1.121933719")
@@ -13,8 +13,8 @@
     (flycheck        "32")
     (async           "1.9.7"))
   :url "https://github.com/gmlarumbe/verilog-ext"
-  :commit "fb7d629688f862e0bdb91986d72bcff2ae7c3e23"
-  :revdesc "fb7d629688f8"
+  :commit "bbf99e16866cdc35bddf04a2e68e7d8664343506"
+  :revdesc "bbf99e16866c"
   :keywords '("verilog" "ide" "tools")
   :authors '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com"))
   :maintainers '(("Gonzalo Larumbe" . "gonzalomlarumbe@gmail.com")))
